==> cmsmadesimple-1.5.3.tgz: cms/modules/TinyMCE/lang/ext/pt_PT.php <==
<?php
$lang['friendlyname'] = 'TinyMCE Editor';
$lang['uninstalled'] = 'M&oacute;dulo Desinstalado.';
$lang['installed'] = 'M&oacute;dulo vers&atilde;o %s instalado.';
$lang['stripbackgroundtags'] = 'Strip tags fundo da CSS';
$lang['source_formatting_text'] = 'Aplicar formata&ccedil;&atilde;o na sa&iacute;da HTML';
$lang['dropdownblockformats_text'] = 'Formato Bloco no menu-dropdown';
$lang['allowtables'] = 'Permitir opera&ccedil;&otilde;es de tabelas ';
$lang['newlinestyle_text'] = 'Nova linha de estilo';
$lang['pstyle'] = 'estilo p';
$lang['brstyle'] = 'estilo br';
$lang['usecompressiontext'] = 'Use compress&atilde;o gz';
$lang['usecompressionhelp'] = 'Isto pode acelerar a carregamento do TinyMCE, mas tamb&eacute;m pode impedi-lo em alguns sistemas. Use com cuidado.';
$lang['forcedrootblocktext'] = 'For&ccedil;ar &quot;p&quot; rootblock';
$lang['forcedrootblockhelp'] = 'For&ccedil;ar no conte&uacute;do, no m&iacute;nimo, a ser inclu&iacute;da em um &quot;p-tag&quot;';
$lang['filepickerstyle'] = 'Estilo do Filepicker';
$lang['filepickersize'] = 'Filepicker Tamanho';
$lang['allowuploadtext'] = 'Permitir o carregamento de imagens, bem como, criar novas pastas no Gestor de Fotos';
$lang['cannotreadconfig'] = 'N&atilde;o &eacute; poss&iacute;vel ler o arquivo  tinyconfig.php directamente o TinyMCE provavelmente n&atilde;o funcionar&aacute;. Deve verificar as permiss&otilde;es do arquivo e da root dirs, que deveria ser lido por todos, mas apenas para o propriet&aacute;rio de escrita.';
$lang['filenameonly'] = 'Mostrar nomes dos ficheiros';
$lang['thumbnailsonly'] = 'Mostrar miniaturas';
$lang['showthumbnailfilestext'] = 'Mostrar miniaturas numa lista';
$lang['filenameandthumbnails'] = 'Mostrar ambos, nomes dos ficheiros e miniaturas';
$lang['skinstext'] = 'Skin (tema)';
$lang['skinvariationtext'] = 'Varia&ccedil;&otilde;es de Skin';
$lang['advancedwarning'] = '<strong> Por favor Note! <br/> Alterar essas configura&ccedil;&otilde;es podem causar uma falha no TinyMCE e deixar de trabalhar, ou, o c&oacute;digo gerado pode ser errado, de alguma forma. S&oacute; edite  se souber o que est&aacute; a fazer! Por favor consulte o website TinyMCE antes de o fazer. </strong>';
$lang['entityencoding_text'] = 'Codifica&ccedil;&atilde;o de entidades';
$lang['rawencoding'] = 'Raw codifica&ccedil;&atilde;o (mais r&aacute;pido, funciona na maioria dos casos)';
$lang['namedencoding'] = 'Codifica&ccedil;&atilde;o (como: &amp;amp;nbsp;)';
$lang['numericencoding'] = 'Codifica&ccedil;&atilde;o Num&eacute;rica (like &amp;#160;)';
$lang['show_path_text'] = 'Mostrar o caminho do elemento na parte inferior do editor.';
$lang['toolbar_tab'] = 'Barra de Ferramentas';
$lang['toolbar_help'] = 'Estas op&ccedil;&otilde;es devem conter uma lista separada por v&iacute;rgulas do bot&atilde;o/controlo, nomes para inserir na barra de ferramentas.';
$lang['toolbar_text'] = 'Barra de Ferramentas';
$lang['toolbarhelptext'] = 'Clique aqui para ver instru&ccedil;&otilde;es na Barra-TinyMCE-wiki.';
$lang['editor_width_text'] = 'Largura do editor';
$lang['editor_height_text'] = 'Altura do editor';
$lang['auto'] = 'Autom&aacute;tico';
$lang['or'] = 'ou';
$lang['datetimeformat_text'] = 'Data/Hora formato';
$lang['timetext'] = 'Hora';
$lang['datetext'] = 'Data';
$lang['datetimeformat_help'] = 'Clique aqui para obter ajuda sobre como formatar a data/hora';
$lang['extraconfigtext'] = 'Configura&ccedil;&atilde;o extra';
$lang['extraconfighelp'] = 'Verifique o TinyMCE-wiki para mais instru&ccedil;&otilde;es';
$lang['customdropdowntext'] = 'Menu Suspenso Personalizado';
$lang['customdropdownhelp'] = 'Insere peda&ccedil;os de c&oacute;digo/texto personaliz&aacute;veis na selec&ccedil;&atilde;o em um menu suspenso.
Acesso a tag&#039;s etc. O menu &eacute; inserido na barra usando &#039;customdropdown&#039;.';
$lang['startenabledtext'] = 'Arranque activado';
$lang['startenabledhelp'] = 'Desmarcar Arranque no Tiny  em um estado desabilitado. Deve ser utilizado juntamente com o bot&atilde;o alternar.';
$lang['loadcmslinkertext'] = 'Carrega o CMSmslinker';
$lang['loadcmslinkerhelp'] = 'Gera o c&oacute;digo javascript necess&aacute;rio para permitir a cmsmslinker a ser adicionado a uma barra de ferramentas.';
$lang['cmslinkerstyletext'] = 'CMS-linker link-estilo';
$lang['cmsselflinkstyle'] = '{cms_selflink}-estilo';
$lang['ahrefstyle'] = 'a href-style-estilo ';
$lang['relativeurlstext'] = 'Gerar urls relativas';
$lang['forcecleanpastetext'] = 'For&ccedil;ar limpeza na colagem';
$lang['forcecleanpastehelp'] = 'Isto deve ser activado para remover c&oacute;digo estranho de formata&ccedil;&atilde;o ao colar do Word etc.';
$lang['bodycss_text'] = 'BodyTag CSS';
$lang['bodycss_help'] = 'Ser&aacute; para adicionar css ao body-tag';
$lang['includeonlyscreencss_text'] = 'Incluir unicamente CSS para monitores (screen)';
$lang['includeonlyscreencss_help'] = 'Esta selec&ccedil;&atilde;o s&oacute; permite que acompanhar este estilo com o monitor-mediatype seleccionados para serem inclu&iacute;dos no estilos TinyMCE .';
$lang['usestaticconfigtext'] = 'Use arquivo est&aacute;tico de config';
$lang['usestaticconfighelp'] = 'Isso pode ajudar o Tiny a trabalhar em sistemas onde tem a instala&ccedil;&atilde;o de hospedagem, acrescenta varias pe&ccedil;as como  todas as estat&iacute;sticas de produ&ccedil;&atilde;o etc., quebrando dinamicamente o criado arquivo de config-javascript';
$lang['usestaticconfigwarning'] = 'Aten&ccedil;&atilde;o! Tem a op&ccedil;&atilde;o est&aacute;tica config-file habilitado mas seu /tmp/dir n&atilde;o tem permiss&otilde;es de escrita. Isso ir&aacute; evitar que o m&oacute;dulo possa salvar no arquivo config-est&aacute;tico e muito provavelmente ir&aacute; tornar o TinyMCE inoperacional.';
$lang['showtogglebutton_text'] = 'Mostrar checkbox para colocar wysiwyg on/off';
$lang['togglewysiwyg'] = 'Colocar Editor on/off';
$lang['styles_tab'] = 'Estilos CSS';
$lang['styles_help'] = 'Se deixar o campo em branco, TinyMCE ir&aacute; analisar seu arquivo CSS e lista os estilos contidos nele para o usu&aacute;rio. Se quiser que apenas alguns estilos sejam apresentados ao usu&aacute;rio, especifique-os sob a forma &quot;Estilo 1 = style1; Estilo 2 = style2&quot; no primeiro campo abaixo. Nos restantes dom&iacute;nios, pode especificar estilos CSS para as tabelas, Linhas e C&eacute;lulas que s&atilde;o utilizados no correspondentes di&aacute;logos. Para um campo vazio, os estilos s&atilde;o usados em geral.
	
		';
$lang['css_styles_text'] = 'Geral';
$lang['accessdenied'] = 'Acesso Negado!';
$lang['error'] = 'Erro!';
$lang['submit'] = 'Submeter';
$lang['update'] = 'Actualizar';
$lang['settings'] = 'Configura&ccedil;&otilde;es';
$lang['settingssaved'] = 'Configura&ccedil;&otilde;es Salvas';
$lang['advancedsaved'] = 'Configura&ccedil;&otilde;es avan&ccedil;adas salvas';
$lang['toolbarsaved'] = 'Barra de Ferramentas Salva';
$lang['stylessaved'] = 'Styles Salvos';
$lang['testareatext'] = 'Teste, sem conte&uacute;do, &eacute; simplesmente teste...';
$lang['reset'] = 'Redefinir padr&atilde;o';
$lang['resetall'] = 'Redefinir todas as configura&ccedil;&otilde;es para as originais';
$lang['confirmreset'] = 'Tem certeza de que deseja redefinir essas configura&ccedil;&otilde;es para seus valores predefinidos?';
$lang['confirmresetall'] = 'Tem certeza de que deseja redefinir todas as configura&ccedil;&otilde;es dos seus padr&otilde;es?';
$lang['settingsreset'] = 'Estas defini&ccedil;&otilde;es foram redefinidas para padr&atilde;o';
$lang['allsettingsreset'] = 'Todos os ajustes foram repostos';
$lang['upgraded'] = 'Foi actualizado';
$lang['customdropdown'] = 'Menu suspenso personalizado';
$lang['cmsmslinker'] = 'Inserir link para uma p&aacute;gina';
$lang['backend_toolbars'] = 'Backend Barra configura&ccedil;&otilde;es';
$lang['frontend_toolbars'] = 'Frontend Barra configura&ccedil;&otilde;es';
$lang['plugins_tab'] = 'Plugins (extras)';
$lang['plugins_help'] = 'Escolha os plugins que pretende activar. Documenta&ccedil;&atilde;o pode ser encontrada em http://wiki.moxiecode.com/index.php/TinyMCE:Plugins';
$lang['plugins_text'] = 'Plugins (extras)';
$lang['saveplugins'] = 'Salvar Plugins';
$lang['pluginssaved'] = 'Plugins Salvos';
$lang['youareintext'] = 'Est&aacute; localizado em';
$lang['loadstylesheettext'] = 'Cargar css do conte&uacute;do (recomendado)';
$lang['extrastylestext'] = 'Adi&ccedil;&otilde;es ao estilo';
$lang['extrastyleshelp'] = 'CSS adicionados aqui ser&atilde;o adicionados ao estilo lido pelo TinyMCE depois de receber os estilos do CMSms';
$lang['uploadnewfile'] = 'Novo ficheiro';
$lang['uploadfile'] = 'Carregar';
$lang['createnewdir'] = 'Nova Pasta';
$lang['createdir'] = 'Criar';
$lang['nodirname'] = 'A pasta n&atilde;o tem um nome v&aacute;lido';
$lang['direxists'] = 'J&aacute; existe um nome para esta pasta';
$lang['newdircreated'] = 'Pasta criada com sucesso';
$lang['newdirfailed'] = 'Ocorreu um erro ao criar a pasta';
$lang['nofile'] = 'N&atilde;o foi carregado nenhum ficheiro';
$lang['filetoobig'] = 'O tamanho do ficheiro ultrapassa o permitido';
$lang['uploadfailed'] = 'Erro ao tentar mover para este local';
$lang['fileuploaded'] = 'Ficheiro carregado com sucesso';
$lang['filepickertitle'] = 'CMS Selec&ccedil;&atilde;o de Ficheiros';
$lang['success'] = 'Sucesso';
$lang['fileoperations'] = 'Opera&ccedil;&otilde;es de Ficheiros';
$lang['thousanddelimiter'] = ', ';
$lang['size'] = 'Tamanho';
$lang['dimensions'] = 'A x L';
$lang['advanced_tab'] = 'Avan&ccedil;ado';
$lang['help'] = '	<h3>What does this do?</h3>
	<p>Enables a TinyMCE to be used as a WYSIWYG.</p>
	<h3>How do I use it?</h3>
	<p>Install it, then go to User Preferences and Set TinyMCE to be your wysiwyg of choice.</p>
	<h3>Troubleshooting</h3>
	Some people have trouble with tiny not showing up upon installation or upgrading. Here is a checklist of 
	things you can try before contacting me for further support.
	<br/>
	<ul>
	<li>1. Please, please, try to reupload the modules/TinyMCE dir to your server. You&#039;d be amazed how many times this has helped people.</li>
	<li>2. Try to switch on the Static Config option. Note that this requires your /tmp/-dir to be writable by the webserver</li>
	<li>3. If upgrading, please try to reset all settings. Not nice if you&#039;ve done a lot of customization, I know, but a lot of things changes from 2.3.x to 2.4.x series of the module.
	<li>4. Try enabling the static config option in advanced settings. This works better on some systems (like CGI-based)
	</ul>
	<br/>
';
$lang['utma'] = '156861353.3475328182428258000.1235609324.1235780246.1235825140.6';
$lang['utmz'] = '156861353.1235747081.4.3.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,31172.0.html';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>

==> cmsmadesimple-1.6.4.tgz: cms/modules/TinyMCE/lang/ext/pt_PT.php <==
<?php
$lang['friendlyname'] = 'TinyMCE Editor';
$lang['uninstalled'] = 'M&oacute;dulo Desinstalado.';
$lang['installed'] = 'M&oacute;dulo vers&atilde;o %s instalado.';
$lang['stripbackgroundtags'] = 'Strip tags fundo da CSS';
$lang['stiptags_help'] = 'Esta op&ccedil;&atilde;o tenta remover o fundo das configura&ccedil;&otilde;es a partir da folha de estilo.';
$lang['source_formatting_text'] = 'Aplicar formata&ccedil;&atilde;o na sa&iacute;da HTML';
$lang['dropdownblockformats_text'] = 'Formato Bloco no menu-dropdown';
$lang['allowtables'] = 'Permitir opera&ccedil;&otilde;es de tabelas ';
$lang['newlinestyle_text'] = 'Nova linha de estilo';
$lang['pstyle'] = 'estilo p';
$lang['brstyle'] = 'estilo br';
$lang['usecompressiontext'] = 'Use compress&atilde;o gz';
$lang['usecompressionhelp'] = 'Isto pode acelerar a carregamento do TinyMCE, mas tamb&eacute;m pode impedi-lo em alguns sistemas. Use com cuidado.';
$lang['forcedrootblocktext'] = 'For&ccedil;ar &quot;p&quot; rootblock';
$lang['forcedrootblockhelp'] = 'For&ccedil;ar no conte&uacute;do, no m&iacute;nimo, a ser inclu&iacute;da em um &quot;p-tag&quot;';
$lang['filepickerstyle'] = 'Estilo do Filepicker';
$lang['filepickersize'] = 'Filepicker Tamanho';
$lang['allowuploadtext'] = 'Permitir o carregamento de imagens, bem como, criar novas pastas no Gestor de Fotos';
$lang['allowscalingtext'] = 'Permitir autom&aacute;ticamente redimensionamento de imagens';
$lang['scalingdimensionstext'] = 'Dimens&otilde;es padr&atilde;o';
$lang['resizeto'] = 'Redimensionar para:';
$lang['useadvancedprofile'] = 'Usar Perfis do TinyMCE avan&ccedil;ados';
$lang['saveprofile'] = 'Guardar Perfile';
$lang['profilesaved'] = 'O Perfile fio guardado';
$lang['profiles_tab'] = 'Perfis';
$lang['advanced_backend_toolbars'] = 'Configura&ccedil;&otilde;es de perfil avan&ccedil;adas no admin painel';
$lang['savestyles'] = 'Guardar estilos';
$lang['allowadvancedprofile'] = 'Permitir o uso de perfis avan&ccedil;ados no TinyMCE';
$lang['showfilemanagement'] = 'Mostrar op&ccedil;&otilde;es no gestor de ficheiros';
$lang['showfilemanagementhelp'] = 'Mostrar no gestor de ficheiros  op&ccedil;&otilde;es como carregar ficheiros, e fazer a elimina&ccedil;&atilde;o de pastas e ficheiros no Gestor de Ficheiros, se o utilizador estiver autorizado a executar as mesmas.';
$lang['deleteconfirmation'] = 'Tem certeza de que o arquivo deve ser apagado?';
$lang['deletefilesuccess'] = 'foi eliminado com sucesso';
$lang['deletefilefila'] = 'n&atilde;o pode ser eliminado';
$lang['cannotreadconfig'] = 'N&atilde;o &eacute; poss&iacute;vel ler o arquivo  tinyconfig.php directamente o TinyMCE provavelmente n&atilde;o funcionar&aacute;. Deve verificar as permiss&otilde;es do arquivo e da root dirs, que deveria ser lido por todos, mas apenas para o propriet&aacute;rio de escrita.';
$lang['filenameonly'] = 'Mostrar nomes dos ficheiros';
$lang['thumbnailsonly'] = 'Mostrar miniaturas';
$lang['showthumbnailfilestext'] = 'Mostrar miniaturas numa lista';
$lang['filenameandthumbnails'] = 'Mostrar ambos, nomes dos ficheiros e miniaturas';
$lang['skinstext'] = 'Skin (tema)';
$lang['skinvariationtext'] = 'Varia&ccedil;&otilde;es de Skin';
$lang['advancedwarning'] = '<strong> Por favor Note! <br/> Alterar essas configura&ccedil;&otilde;es podem causar uma falha no TinyMCE e deixar de trabalhar, ou, o c&oacute;digo gerado pode ser errado, de alguma forma. S&oacute; edite  se souber o que est&aacute; a fazer! Por favor consulte o website TinyMCE antes de o fazer. </strong>';
$lang['entityencoding_text'] = 'Codifica&ccedil;&atilde;o de entidades';
$lang['rawencoding'] = 'Raw codifica&ccedil;&atilde;o (mais r&aacute;pido, funciona na maioria dos casos)';
$lang['namedencoding'] = 'Codifica&ccedil;&atilde;o (como: &amp;amp;nbsp;)';
$lang['numericencoding'] = 'Codifica&ccedil;&atilde;o Num&eacute;rica (like &amp;#160;)';
$lang['show_path_text'] = 'Mostrar o caminho do elemento na parte inferior do editor.';
$lang['toolbar_tab'] = 'Barra de Ferramentas';
$lang['toolbar_help'] = 'Estas op&ccedil;&otilde;es devem conter uma lista separada por v&iacute;rgulas do bot&atilde;o/controlo, nomes para inserir na barra de ferramentas.';
$lang['toolbar_text'] = 'Barra de Ferramentas';
$lang['toolbarhelptext'] = 'Clique aqui para ver instru&ccedil;&otilde;es na Barra-TinyMCE-wiki.';
$lang['editor_width_text'] = 'Largura do editor';
$lang['editor_height_text'] = 'Altura do editor';
$lang['auto'] = 'Autom&aacute;tico';
$lang['or'] = 'ou';
$lang['datetimeformat_text'] = 'Data/Hora formato';
$lang['timetext'] = 'Hora';
$lang['datetext'] = 'Data';
$lang['datetimeformat_help'] = 'Clique aqui para obter ajuda sobre como formatar a data/hora';
$lang['extraconfigtext'] = 'Configura&ccedil;&atilde;o extra';
$lang['extraconfighelp'] = 'Verifique o TinyMCE-wiki para mais instru&ccedil;&otilde;es';
$lang['customdropdowntext'] = 'Menu Suspenso Personalizado';
$lang['customdropdownhelp'] = 'Insere peda&ccedil;os de c&oacute;digo/texto personaliz&aacute;veis na selec&ccedil;&atilde;o em um menu suspenso.
Acesso a tag&#039;s etc. O menu &eacute; inserido na barra usando &#039;customdropdown&#039;.';
$lang['startenabledtext'] = 'Arranque activado';
$lang['startenabledhelp'] = 'Desmarcar Arranque no Tiny  em um estado desabilitado. Deve ser utilizado juntamente com o bot&atilde;o alternar.';
$lang['loadcmslinkertext'] = 'Carrega o CMSmslinker';
$lang['loadcmslinkerhelp'] = 'Gera o c&oacute;digo javascript necess&aacute;rio para permitir a cmsmslinker a ser adicionado a uma barra de ferramentas.';
$lang['cmslinkerstyletext'] = 'CMS-linker link-estilo';
$lang['cmsselflinkstyle'] = '{cms_selflink}-estilo';
$lang['ahrefstyle'] = 'a href-style-estilo ';
$lang['relativeurlstext'] = 'Gerar urls relativas';
$lang['forcecleanpastetext'] = 'For&ccedil;ar limpeza na colagem';
$lang['forcecleanpastehelp'] = 'Isto deve ser activado para remover c&oacute;digo estranho de formata&ccedil;&atilde;o ao colar do Word etc.';
$lang['bodycss_text'] = 'BodyTag CSS';
$lang['bodycss_help'] = 'Ser&aacute; para adicionar css ao body-tag';
$lang['includeonlyscreencss_text'] = 'Incluir unicamente CSS para monitores (screen)';
$lang['includeonlyscreencss_help'] = 'Esta selec&ccedil;&atilde;o s&oacute; permite que acompanhar este estilo com o monitor-mediatype seleccionados para serem inclu&iacute;dos no estilos TinyMCE .';
$lang['usestaticconfigtext'] = 'Use arquivo est&aacute;tico de config';
$lang['usestaticconfighelp'] = 'Isso pode ajudar o Tiny a trabalhar em sistemas onde tem a instala&ccedil;&atilde;o de hospedagem, acrescenta varias pe&ccedil;as como  todas as estat&iacute;sticas de produ&ccedil;&atilde;o etc., quebrando dinamicamente o criado arquivo de config-javascript';
$lang['usestaticconfigwarning'] = 'Aten&ccedil;&atilde;o! Tem a op&ccedil;&atilde;o est&aacute;tica config-file habilitado mas seu /tmp/dir n&atilde;o tem permiss&otilde;es de escrita. Isso ir&aacute; evitar que o m&oacute;dulo possa salvar no arquivo config-est&aacute;tico e muito provavelmente ir&aacute; tornar o TinyMCE inoperacional.';
$lang['showtogglebutton_text'] = 'Mostrar checkbox para colocar wysiwyg on/off';
$lang['togglewysiwyg'] = 'Colocar Editor on/off';
$lang['styles_tab'] = 'Estilos CSS';
$lang['styles_help'] = 'Se deixar o campo em branco, TinyMCE ir&aacute; analisar seu arquivo CSS e lista os estilos contidos nele para o usu&aacute;rio. Se quiser que apenas alguns estilos sejam apresentados ao usu&aacute;rio, especifique-os sob a forma &quot;Estilo 1 = style1; Estilo 2 = style2&quot; no primeiro campo abaixo. Nos restantes dom&iacute;nios, pode especificar estilos CSS para as tabelas, Linhas e C&eacute;lulas que s&atilde;o utilizados no correspondentes di&aacute;logos. Para um campo vazio, os estilos s&atilde;o usados em geral.
	
		';
$lang['css_styles_text'] = 'Geral';
$lang['accessdenied'] = 'Acesso Negado!';
$lang['error'] = 'Erro!';
$lang['submit'] = 'Submeter';
$lang['update'] = 'Actualizar';
$lang['savesettings'] = 'Guardar configura&ccedil;&otilde;es';
$lang['settings'] = 'Configura&ccedil;&otilde;es';
$lang['settingssaved'] = 'Configura&ccedil;&otilde;es Salvas';
$lang['saveadvanced'] = 'Guardar configura&ccedil;&otilde;es avan&ccedil;adas';
$lang['advancedsaved'] = 'Configura&ccedil;&otilde;es avan&ccedil;adas guardadas';
$lang['toolbarsaved'] = 'Barra de Ferramentas guardada';
$lang['stylessaved'] = 'Estilos guardados';
$lang['testareatext'] = '<p>Teste, sem conte&uacute;do, &eacute; simplesmente teste...</p>';
$lang['reset'] = 'Redefinir padr&atilde;o';
$lang['resetall'] = 'Redefinir todas as configura&ccedil;&otilde;es para as originais';
$lang['confirmreset'] = 'Tem certeza de que deseja redefinir essas configura&ccedil;&otilde;es para seus valores predefinidos?';
$lang['confirmresetall'] = 'Tem certeza de que deseja redefinir todas as configura&ccedil;&otilde;es dos seus padr&otilde;es?';
$lang['settingsreset'] = 'Estas defini&ccedil;&otilde;es foram redefinidas para padr&atilde;o';
$lang['allsettingsreset'] = 'Todos os ajustes foram repostos';
$lang['upgraded'] = 'Foi actualizado';
$lang['customdropdown'] = 'Menu suspenso personalizado';
$lang['cmsmslinker'] = 'Inserir link para uma p&aacute;gina';
$lang['backend_toolbars'] = 'Backend Barra configura&ccedil;&otilde;es';
$lang['frontend_toolbars'] = 'Frontend Barra configura&ccedil;&otilde;es';
$lang['plugins_tab'] = 'Plugins (extras)';
$lang['plugins_help'] = 'Escolha os plugins que pretende activar. Documenta&ccedil;&atilde;o pode ser encontrada em http://wiki.moxiecode.com/index.php/TinyMCE:Plugins';
$lang['plugins_text'] = 'Plugins (extras)';
$lang['saveplugins'] = 'Salvar Plugins';
$lang['pluginssaved'] = 'Plugins Salvos';
$lang['youareintext'] = 'Est&aacute; localizado em';
$lang['loadstylesheettext'] = 'Cargar css do conte&uacute;do (recomendado)';
$lang['extrastylestext'] = 'Adi&ccedil;&otilde;es ao estilo';
$lang['extrastyleshelp'] = 'CSS adicionados aqui ser&atilde;o adicionados ao estilo lido pelo TinyMCE depois de receber os estilos do CMSms';
$lang['uploadnewfile'] = 'Novo ficheiro';
$lang['uploadfile'] = 'Carregar';
$lang['createnewdir'] = 'Nova Pasta';
$lang['createdir'] = 'Criar';
$lang['nodirname'] = 'A pasta n&atilde;o tem um nome v&aacute;lido';
$lang['direxists'] = 'J&aacute; existe um nome para esta pasta';
$lang['newdircreated'] = 'Pasta criada com sucesso';
$lang['newdirfailed'] = 'Ocorreu um erro ao criar a pasta';
$lang['nofile'] = 'N&atilde;o foi carregado nenhum ficheiro';
$lang['filetoobig'] = 'O tamanho do ficheiro ultrapassa o permitido';
$lang['uploadfailed'] = 'Erro ao tentar mover para este local';
$lang['fileuploaded'] = 'Ficheiro carregado com sucesso';
$lang['filepickertitle'] = 'CMS Selec&ccedil;&atilde;o de Ficheiros';
$lang['success'] = 'Sucesso';
$lang['fileoperations'] = 'Opera&ccedil;&otilde;es de Ficheiros';
$lang['thousanddelimiter'] = ', ';
$lang['size'] = 'Tamanho';
$lang['dimensions'] = 'A x L';
$lang['advanced_tab'] = 'Avan&ccedil;ado';
$lang['help'] = '	<h3>What does this do?</h3>
	<p>Enables a TinyMCE to be used as a WYSIWYG.</p>
	<h3>How do I use it?</h3>
	<p>Install it, then go to User Preferences and Set TinyMCE to be your wysiwyg of choice.</p>
	<h3>Troubleshooting</h3>
	Some people have trouble with tiny not showing up upon installation or upgrading. Here is a checklist of 
	things you can try before contacting me for further support.
	<br/>
	<ul>
	<li>1. Please, please, try to reupload the modules/TinyMCE dir to your server. You&#039;d be amazed how many times this has helped people.</li>
	<li>2. Try to switch on the Static Config option. Note that this requires your /tmp/-dir to be writable by the webserver</li>
	<li>3. If upgrading, please try to reset all settings. Not nice if you&#039;ve done a lot of customization, I know, but a lot of things changes from 2.3.x to 2.4.x series of the module.
	<li>4. Try enabling the static config option in advanced settings. This works better on some systems (like CGI-based)
	</ul>
	<br/>
';
$lang['utma'] = '156861353.3089450601847726600.1241711306.1242653258.1242681672.52';
$lang['utmz'] = '156861353.1242681672.52.18.utmcsr=patriciavaz.nunodev.homelinux.com|utmccn=(referral)|utmcmd=referral|utmcct=/site/';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.1.10.1242681672';
?>
